==> sadad_payment_flutter-0.0.35.tar.gz: lib/apputils/appdialogs.dart <==
import 'package:flutter/material.dart';
import 'package:sadad_payment_flutter/apputils/appcolors.dart';
import 'package:sadad_payment_flutter/apputils/appstrings.dart';

class AppDialog {
  static showProcess(BuildContext context,Color progressColor) {
    return showDialog(
      barrierDismissible: false,
      context: context,
      builder: (context) {
        return Dialog(
          elevation: 0,
          backgroundColor: AppColors.transparent,
          child: WillPopScope(
            child: Center(
                child: CircularProgressIndicator(
              color: progressColor,
            )),
            onWillPop: () => Future.value(false),
          ),
        );
      },
    );
  }

  static commonWarningDialog({required final BuildContext context, required String title, required String subTitle, required String buttonText, required Function() buttonOnTap}) {
    showDialog(
      barrierDismissible: false,
      context: context,
      builder: (context) {
        return WillPopScope(
          onWillPop: () => Future.value(false),
          child: Dialog(
            backgroundColor: AppColors.transparent,
            child: Container(
                padding: EdgeInsets.all(12),
                decoration: BoxDecoration(color: AppColors.white, borderRadius: BorderRadius.circular(10)),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    SizedBox(height: 8),
                    Text(
                      title,
                      style: TextStyle(fontSize: 20, fontFamily: AppConstant.robotoText),
                    ),
                    const SizedBox(height: 10),
                    Text(
                      subTitle,
                      style: TextStyle(fontSize: 15, fontFamily: AppConstant.robotoText),textAlign: TextAlign.center,
                    ),
                    const SizedBox(height: 20),
                    InkWell(
                      onTap: buttonOnTap,
                      child: Container(
                        height: 50,
                        width: 100,
                        decoration: BoxDecoration(color: AppColors.primaryColor, borderRadius: BorderRadius.circular(10)),
                        child: Center(
                            child: Text(
                          buttonText,
                          style: TextStyle(color: AppColors.white, fontSize: 16),
                        )),
                      ),
                    ),
                    SizedBox(height: 8)
                  ],
                )),
          ),
        );
      },
    );
  }
}

==> sadad_payment_flutter-0.0.37.tar.gz: lib/apputils/appdialogs.dart <==
import 'package:flutter/material.dart';
import 'package:sadad_payment_flutter/apputils/appcolors.dart';
import 'package:sadad_payment_flutter/apputils/appstrings.dart';

class AppDialog {
  static showProcess(BuildContext context,Color progressColor) {
    return showDialog(
      barrierDismissible: false,
      context: context,
      builder: (context) {
        return Dialog(
          elevation: 0,
          backgroundColor: AppColors.transparent,
          child: WillPopScope(
            child: Center(
                child: CircularProgressIndicator(
              color: progressColor,
            )),
            onWillPop: () => Future.value(false),
          ),
        );
      },
    );
  }

  static commonWarningDialog({required final BuildContext context, required String title, required String subTitle, required String buttonText, required Function() buttonOnTap,required bool useMobileLayout}) {
    showDialog(
      barrierDismissible: false,
      context: context,
      builder: (context) {
        return WillPopScope(
          onWillPop: () => Future.value(false),
          child: Dialog(
            backgroundColor: AppColors.transparent,
            child: Container(
                padding: EdgeInsets.all(12),
                decoration: BoxDecoration(color: AppColors.white, borderRadius: BorderRadius.circular(10)),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    SizedBox(height: 8),
                    Text(
                      title,
                      style: TextStyle(fontSize:useMobileLayout ? 20: 24, fontFamily: AppConstant.robotoText),
                    ),
                    const SizedBox(height: 10),
                    Text(
                      subTitle,
                      style: TextStyle(fontSize: 15, fontFamily: AppConstant.robotoText),textAlign: TextAlign.center,
                    ),
                    const SizedBox(height: 20),
                    InkWell(
                      onTap: buttonOnTap,
                      child: Container(
                        height: 50,
                        width: 100,
                        decoration: BoxDecoration(color: AppColors.primaryColor, borderRadius: BorderRadius.circular(10)),
                        child: Center(
                            child: Text(
                          buttonText,
                          style: TextStyle(color: AppColors.white, fontSize: 16),
                        )),
                      ),
                    ),
                    SizedBox(height: 8)
                  ],
                )),
          ),
        );
      },
    );
  }
}
